#
# spec file for package dino
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with    separated_plugins
%bcond_with    separated_libs
%if 0%{?suse_version}
%bcond_without shared_libsignal
%else
%bcond_with    shared_libsignal
%endif

Name:           dino
Version:        0.4.3
Release:        1.4
Summary:        Modern Jabber/XMPP Client using GTK+/Vala
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/dino/dino
Source:         https://github.com/dino/dino/releases/download/v%{version}/dino-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
%if 0%{?suse_version}
BuildRequires:  libgpgme-devel
BuildRequires:  libgpgmepp-devel
%else
BuildRequires:  gpgme-devel
%endif
BuildRequires:  libgcrypt-devel
BuildRequires:  libnotify-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.30
BuildRequires:  pkgconfig(gee-0.8) >= 0.10
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.38
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-rtp-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(nice) >= 0.1.15
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webrtc-audio-processing)
%if %{with shared_libsignal}
BuildRequires:  pkgconfig(libsignal-protocol-c) >= 2.3.2
%endif
Requires:       hicolor-icon-theme
%if "%{_lib}" == "lib64"
Requires:       gstreamer1(element-gtksink)()(64bit)
%else
Requires:       gstreamer1(element-gtksink)
%endif
%if %{with separated_plugins}
Recommends:     %{name}-plugin-http-upload   = %{version}
Recommends:     %{name}-plugin-omemo         = %{version}
Recommends:     %{name}-plugin-openpgp       = %{version}
%else
Provides:       %{name}-plugin-openpgp       = %{version}
Obsoletes:      %{name}-plugin-openpgp       < %{version}
Provides:       %{name}-plugin-omemo         = %{version}
Obsoletes:      %{name}-plugin-omemo         < %{version}
Provides:       %{name}-plugin-http-upload   = %{version}
Obsoletes:      %{name}-plugin-http-upload   < %{version}
%endif

%define libdino libdino0
%define libqlite libqlite0
%define libcryptovala libcrypto-vala0
%define libxmppvala libxmpp-vala0

%if ! %{with separated_libs}
Provides:       %{libdino} = %{version}-%{release}
Obsoletes:      %{libdino} < %{version}-%{release}
Provides:       %{libqlite} = %{version}-%{release}
Obsoletes:      %{libqlite} < %{version}-%{release}
Provides:       %{libcryptovala} = %{version}-%{release}
Obsoletes:      %{libcryptovala} < %{version}-%{release}
Provides:       %{libxmppvala} = %{version}-%{release}
Obsoletes:      %{libxmppvala} < %{version}-%{release}

%endif

%description
Dino is an instant messaging client for the Jabber/XMPP network,
providing a unique and modern user experience based on the latest
technology from the GNOME project. Dino is still in early
development and has limited features, but already has basic support
for XMPP's latest encryption features. Future versions will provide
a plug-in API, so that developers can easily add new optional
features.

%package -n     %{libdino}
Summary:        Library libdino of %{name}
Group:          Productivity/Networking/Instant Messenger

%description -n %{libdino}
The package contains libraries used and provided by %{name}.

%package -n     %{libqlite}
Summary:        Library libqlite of %{name}
Group:          Productivity/Networking/Instant Messenger

%description -n %{libqlite}
The package contains libraries used and provided by %{name}.

%package -n     %{libcryptovala}
Summary:        Library libcrypto-vala of %{name}
Group:          Productivity/Networking/Instant Messenger

%description -n %{libcryptovala}
The package contains libraries used and provided by %{name}.

%package -n     %{libxmppvala}
Summary:        Library libxmpp-vala of %{name}
Group:          Productivity/Networking/Instant Messenger

%description -n %{libxmppvala}
The package contains libraries used and provided by %{name}.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Languages/Other

%if %{with separated_libs}
Requires:       %{libcryptovala} = %{version}
Requires:       %{libdino}       = %{version}
Requires:       %{libqlite}      = %{version}
Requires:       %{libxmppvala}   = %{version}
%else
Requires:       %{name}          = %{version}
%endif

%description    devel
Contains libraries and header files for developing plugins for %{name}.

%if %{with separated_plugins}
%package        plugin-openpgp
Summary:        OpenPGP plugin for %{name}
Group:          Productivity/Networking/Instant Messenger

%description    plugin-openpgp
Contains the OpenPGP plugin for %{name}.

%package        plugin-omemo
Summary:        OMEMO plugin for %{name}
Group:          Productivity/Networking/Instant Messenger

%description    plugin-omemo
Contains the OMEMO plugin for %{name}.

%package        plugin-http-upload
Summary:        HTTP Upload plugin for %{name}
Group:          Productivity/Networking/Instant Messenger

%description    plugin-http-upload
Contains the HTTP Upload plugin for %{name}.
%endif

%prep
%setup -q

%build
# workaround until we clarified if the gcc return type check is actually wrong there.
%if 0%{?suse_version} >= 1550
export CFLAGS="%{optflags} -Wno-return-type"
%endif
echo "PRERELEASE %{version}" > VERSION
cmake -B build -DUSE_SOUP3=1
%configure \
%if ! %{with shared_libsignal}
  --with-libsignal-in-tree
%endif
#cmake                                          \
# -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed"    \
# -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed" \
# -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed"
cmake -B build -DUSE_SOUP3=1
make %{?_smp_mflags} V=1

%install
cmake -B build -DUSE_SOUP3=1
#cmake_install
make install DESTDIR="%{buildroot}" V=1
# desktop-file-validate %{buildroot}%{_datadir}/applications/dino.desktop

%find_lang dino
%find_lang dino-omemo
%find_lang dino-openpgp
#find_lang dino-http-files

%if 0%{?suse_version}
%post
%if ! %{with separated_libs}
/sbin/ldconfig
%endif
%icon_theme_cache_post

%postun
%if ! %{with separated_libs}
/sbin/ldconfig
%endif
%icon_theme_cache_postun
%else

%post
%if ! %{with separated_libs}
/sbin/ldconfig
%endif
update-desktop-database &>/dev/null || :
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
%if ! %{with separated_libs}
/sbin/ldconfig
%endif
update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
  touch --no-create %{_datadir}/icons/hicolor &>/dev/null
  gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor &>/dev/null || :
%endif

%if %{with separated_libs}
%post   -n %{libdino} -p /sbin/ldconfig
%postun -n %{libdino} -p /sbin/ldconfig

%post   -n %{libqlite} -p /sbin/ldconfig
%postun -n %{libqlite} -p /sbin/ldconfig

%post   -n %{libcryptovala} -p /sbin/ldconfig
%postun -n %{libcryptovala} -p /sbin/ldconfig

%post   -n %{libxmppvala} -p /sbin/ldconfig
%postun -n %{libxmppvala} -p /sbin/ldconfig
%endif

%if %{with separated_plugins}
%files -f dino.lang
%else

%files -f dino.lang -f dino-omemo.lang -f dino-openpgp.lang
%endif
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_bindir}/dino
%dir %{_libdir}/dino
%dir %{_libdir}/dino/plugins
%if ! %{with separated_plugins}
%{_libdir}/dino/plugins/*.so
%endif
%{_datadir}/applications/im.dino.Dino.desktop
%{_datadir}/dbus-1/services/im.dino.Dino.service
%{_datadir}/icons/hicolor/*/apps/*dino*
%{_datadir}/metainfo/im.dino.Dino.appdata.xml
%if ! %{with separated_libs}
%{_libdir}/libdino.so.*
%{_libdir}/libqlite.so.*
%{_libdir}/libcrypto-vala.so.*
%{_libdir}/libxmpp-vala.so.*
%endif

%if %{with separated_libs}
%files -n %{libdino}
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_libdir}/libdino.so.*

%files -n %{libqlite}
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_libdir}/libqlite.so.*

%files -n %{libxmppvala}
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_libdir}/libxmpp-vala.so.*
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/*.h
%{_libdir}/libdino.so
%{_libdir}/libqlite.so
%{_libdir}/libcrypto-vala.so
%{_libdir}/libxmpp-vala.so
%{_datadir}/vala/vapi/*.{vapi,deps}

%if %{with separated_plugins}
%files plugin-openpgp -f dino-openpgp.lang
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_libdir}/dino/plugins/openpgp.so

%files plugin-omemo -f dino-omemo.lang
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_libdir}/dino/plugins/omemo.so

%files plugin-http-upload
#-f dino-http-files.lang
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_libdir}/dino/plugins/http-files.so
%endif

%changelog
* Mon Jul 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.3:
  * Fix video for cameras with rotated image
  * Fix call window controlls hiding
  * Fix call window styling
  * Fix empty alias being handled different than none
  * Fix crash on NS_URI call when own server has no MAM;
    drop broken mam: 1 "support" #1405
  * Focus ChatInput textbox after selecting emoji
  * Fix character counting for fallbacks #1420
  * Fix chat input status having a fixed width requirement #1439
  * Fix chat input for IME #1419
  * Fix reactions being made to the wrong message #1426
  * data: Set X-Purism-FormFactor in .desktop file
  * Ignore non-DTLS data before handshake is complete
  * Do not send DTLS datagrams to RTP even after handshake
  * Fix certificate start time
  * Fix potential crash in video calls
* Fri Mar 24 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.2:
  * Maintenance release with fix for CVE-2023-28686 and bug fixes.
    See https://dino.im/security/cve-2023-28686
* Fri Mar  3 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1 bugfix release:
  * Consider stream readable when EOS is reached
  * Fix critical warnings after DTLS-SRTP calls without OMEMO verification
  * Fix typing notifications in groupchats
  * Fix some memory leaks
  * Stop regenerating message menu buttons
  * Clear chat input after /command
  * Remove spell check setting
* Wed Feb  8 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  See https://dino.im/blog/2023/02/dino-0.4-release/
* Fri Nov  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.3.1:
  * Maintenance release for libsoup3 support and bug fixes
- Remove dino-0.3.0-libsoup.patch
* Fri Oct 28 2022 Michael Vetter <mvetter@suse.com>
- boo#1204259: Add dino-0.3.0-libsoup.patch
* Tue Oct 11 2022 Michael Vetter <mvetter@suse.com>
- Fix build by using ninja instead of make for building
  See https://github.com/dino/dino/issues/1281
* Sun Feb 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.3:
  See https://dino.im/blog/2022/02/dino-0.3-release/
* Thu Sep 23 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.2.2:
  * Maintenance release for GTK+ 3.24.30 support and bug fixes.
* Mon Sep 20 2021 Michael Vetter <mvetter@suse.com>
- Update to stable version 0.2.1
* Mon Sep 20 2021 Michael Vetter <mvetter@suse.com>
- Use libsignal package instead of intree
- Look for libsignal-protocol-c >= 2.3.2 and not nust 2.3.2
  since we have 2.3.3 in Factory
* Mon Jun 11 2018 mrueckert@suse.de
- use intree libsignal for now
* Wed May  2 2018 mvetter@suse.com
- Add appdata file
* Sun Dec  3 2017 mrueckert@suse.de
- adapt to new paths
* Sun Sep  3 2017 mrueckert@suse.de
- only require the libraries if we actually use split libraries
  otherwise require the main package in the devel package
* Thu Aug 31 2017 mrueckert@suse.de
- use project based email instead of our generic list
* Tue Aug 29 2017 mrueckert@suse.de
- merge the shared library back into the main package
* Thu Aug 17 2017 mrueckert@suse.de
- Update to version 0.0~git142.781d241:
  * Http file upload
  * request history since last known messages (#110)
  * Http file upload for version :0 and other server setups
  * http files: Fix double-free rance-condition ... and move classes around
  * http files: Fix for servers w/o file size limit
  * SRV records for XMPP over TLS
  * RosterList: Disconnect handlers on widget destroy Fixes #119
  * xmpp-vala: improve namespace handling, add some tests
  * Stream Management
  * xmpp-vala: Remove require-functions
  * openpgp: contact details provider (fingerprint), colored fingerprints, fix shown availability
  * Update translations Chinese (Simplified): tonghuix Dutch: Nathan Follens Esperanto: Tirifto French: Jean-Baptiste German: rugk Italian: Valerio Baldisserotto Spanish: sergio
  * Message Archive Management
  * fixup 4aee957 (request history since last known messages)
  * Undo/redo text in chat input
  * add DOAP (description of a project) file
  * libdino: do not process message twice
  * xmpp-vala: catch TLS errors during read()
  * libdino: remove dependency to GTK+ (all GTK+ code is in main+plugins)
  * add plugin api for text commands
* Sat Aug 12 2017 mrueckert@suse.de
- enable shared libsignal-protocol-c
* Tue Aug  8 2017 mrueckert@suse.de
- merge with upstream spec file for fedora building
* Sat Aug  5 2017 mrueckert@suse.de
- actually stop using split plugins
* Sat Aug  5 2017 mrueckert@suse.de
- enable http upload plugin
- add support for building without split out plugins
* Mon Jul 17 2017 mrueckert@suse.de
- Update to version 0.0~git122.f83e118:
  * Update translations
  * fixup 5ba95ef (Conversation details dialog)
  * Muc Invite + Kick
  * MUC join behaviour + small MUC error changes
  * Get rid of manual storage objects for delegates
  * Set jid handle in ContactDetails, use LabelHybrids more, remove edit from StartConversation
  * Session establishment
  * Make session negotiation optional
  * tito: add version file to remove warning
  * Small i18n fixes (#53)
* Wed Jun 14 2017 mrueckert@suse.de
- Update to version 0~git1497377560.7bbbb73:
  * Roster versioning
  * fixup bcb9690 (Roster versioning)
  * MUC config form (data forms), MUC room info
  * Notifications + typing notifications + message marker settings per conversation
  * Conversation details dialog
  * Update translations
  * fixup 5ba95ef (Conversation details dialog)
  * Muc Invite + Kick
  * MUC join behaviour + small MUC error changes
  * Get rid of manual storage objects for delegates
* Thu Apr 27 2017 mrueckert@suse.de
- Update to version 0~git1493236133.9728e83:
  * Replace OpenSSL with GCrypt
  * Make gdk-x11 optional
  * Handle conference bookmarks w/o nick
  * qlite: cleanup, fix nullity issues
  * xmpp-vala/core+libdino: concurrency + nullity improvements
  * signal-protocol/omemo: fix null-pointer issues
  * signal-protocol: use proper types and fix memleak (#59)
  * Sync MUC join/part behaviour with autojoin flag in bookmarks
  * cmake/signal-protocol: shared lib, mark_as_advanced and others
  * qlite/libdino: optimize db access
* Thu Apr 27 2017 mrueckert@suse.de
- Update to version 0~git1493236133.9728e83:
  * cmake/signal-protocol: shared lib, mark_as_advanced and others
  * qlite/libdino: optimize db access
* Mon Apr 24 2017 mrueckert@suse.de
- Update to version 0~git1492949024.3eb9aa0:
  * MUC improvements
  * gettext improvements (more strings, times, plural, de lang)
  * Replace OpenSSL with GCrypt
  * Make gdk-x11 optional
  * Handle conference bookmarks w/o nick
  * qlite: cleanup, fix nullity issues
  * xmpp-vala/core+libdino: concurrency + nullity improvements
  * signal-protocol/omemo: fix null-pointer issues
  * signal-protocol: use proper types and fix memleak (#59)
  * Sync MUC join/part behaviour with autojoin flag in bookmarks
* Fri Apr 21 2017 mrueckert@suse.de
- Update to version 0~git1492626696.5c8275e:
  * Add gettext dependency
  * MUC improvements
  * gettext improvements (more strings, times, plural, de lang)
  * Replace OpenSSL with GCrypt
  * Make gdk-x11 optional
  * Handle conference bookmarks w/o nick
  * qlite: cleanup, fix nullity issues
  * xmpp-vala/core+libdino: concurrency + nullity improvements
  * signal-protocol/omemo: fix null-pointer issues
  * signal-protocol: use proper types and fix memleak (#59)
* Wed Apr 19 2017 mvetter@suse.com
- Fix description for plugin-omemo
* Tue Apr 18 2017 mrueckert@suse.de
- Switch to build time services instead of manual tarballs:
  run "osc service ra" to get a tarball for a local build.
  To trigger an update of the server side package run:
  "osc service rr"
- Switch to proper shared library packaging policy:
  - drop dino-libs
- Rename dino-libs-devel to dino-devel and drop the rpmlintrc
- Enable omemo plugin and add subpackage and recommends for it
- Use the find_lang macros to find the language files
- Prepare to use cmake macros instead of the %%configure wrapper
  - Overwrite linker flags to not pass the -z now flag as long we
    use the intree copy of libsignal-protocol-c
* Tue Apr 18 2017 mrueckert@suse.de
- Update to version 0~git1492539641.7e388fb:
  * Fix alt-tab behaviour when notification is active
  * Add gettext dependency
  * MUC improvements
  * gettext improvements (more strings, times, plural, de lang)
  * Replace OpenSSL with GCrypt
  * Make gdk-x11 optional
  * Handle conference bookmarks w/o nick
  * qlite: cleanup, fix nullity issues
  * xmpp-vala/core+libdino: concurrency + nullity improvements
  * signal-protocol/omemo: fix null-pointer issues
* Sun Apr 16 2017 mvetter@suse.com
- add dino-rpmlintrc:
  Allow .so in dino-libs-devel. Probably the warning happens
  because it checks for dino-devel
* Sat Apr 15 2017 mvetter@suse.com
- Update to commit e3b6953
- Prepare for using libsignal-protocol-c from distro.
  Dino cannot handle it yet though.
- Use pkgconfig for BuildRequires
- New packages: dino-libs, dino-libs-devel, dino-openpgp-plugin
* Mon Apr  3 2017 mrueckert@suse.de
- update to the latest git changes
* Thu Mar 30 2017 mvetter@suse.com
- Update to commit e910b39
- Disable omemo plugin until we have libsignal-protocol-c packaged
  (See https://github.com/WhisperSystems/libsignal-protocol-c/issues/59)
- Install all files properly
* Fri Mar 17 2017 mvetter@suse.com
- Initial test package for openSUSE based upon git commit d3005bc
